==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ShiftActivity.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.enums.ScheduleEntityTheme;

@JsonPropertyOrder({
    "@odata.type", 
    "isPaid", 
    "startDateTime", 
    "endDateTime", 
    "code", 
    "displayName", 
    "theme"})
@JsonInclude(Include.NON_NULL)
public class ShiftActivity implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("isPaid")
    protected Boolean isPaid;

    @JsonProperty("startDateTime")
    protected OffsetDateTime startDateTime;

    @JsonProperty("endDateTime")
    protected OffsetDateTime endDateTime;

    @JsonProperty("code")
    protected String code;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("theme")
    protected ScheduleEntityTheme theme;

    protected ShiftActivity() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.shiftActivity";
    }

    @Property(name="isPaid")
    @JsonIgnore
    public Optional<Boolean> getIsPaid() {
        return Optional.ofNullable(isPaid);
    }

    public ShiftActivity withIsPaid(Boolean isPaid) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.isPaid = isPaid;
        return _x;
    }

    @Property(name="startDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getStartDateTime() {
        return Optional.ofNullable(startDateTime);
    }

    public ShiftActivity withStartDateTime(OffsetDateTime startDateTime) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.startDateTime = startDateTime;
        return _x;
    }

    @Property(name="endDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getEndDateTime() {
        return Optional.ofNullable(endDateTime);
    }

    public ShiftActivity withEndDateTime(OffsetDateTime endDateTime) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.endDateTime = endDateTime;
        return _x;
    }

    @Property(name="code")
    @JsonIgnore
    public Optional<String> getCode() {
        return Optional.ofNullable(code);
    }

    public ShiftActivity withCode(String code) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.code = code;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ShiftActivity withDisplayName(String displayName) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="theme")
    @JsonIgnore
    public Optional<ScheduleEntityTheme> getTheme() {
        return Optional.ofNullable(theme);
    }

    public ShiftActivity withTheme(ScheduleEntityTheme theme) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.theme = theme;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean isPaid;
        private OffsetDateTime startDateTime;
        private OffsetDateTime endDateTime;
        private String code;
        private String displayName;
        private ScheduleEntityTheme theme;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder isPaid(Boolean isPaid) {
            this.isPaid = isPaid;
            this.changedFields = changedFields.add("isPaid");
            return this;
        }

        public Builder startDateTime(OffsetDateTime startDateTime) {
            this.startDateTime = startDateTime;
            this.changedFields = changedFields.add("startDateTime");
            return this;
        }

        public Builder endDateTime(OffsetDateTime endDateTime) {
            this.endDateTime = endDateTime;
            this.changedFields = changedFields.add("endDateTime");
            return this;
        }

        public Builder code(String code) {
            this.code = code;
            this.changedFields = changedFields.add("code");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder theme(ScheduleEntityTheme theme) {
            this.theme = theme;
            this.changedFields = changedFields.add("theme");
            return this;
        }

        public ShiftActivity build() {
            ShiftActivity _x = new ShiftActivity();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.shiftActivity";
            _x.isPaid = isPaid;
            _x.startDateTime = startDateTime;
            _x.endDateTime = endDateTime;
            _x.code = code;
            _x.displayName = displayName;
            _x.theme = theme;
            return _x;
        }
    }

    private ShiftActivity _copy() {
        ShiftActivity _x = new ShiftActivity();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.isPaid = isPaid;
        _x.startDateTime = startDateTime;
        _x.endDateTime = endDateTime;
        _x.code = code;
        _x.displayName = displayName;
        _x.theme = theme;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ShiftActivity[");
        b.append("isPaid=");
        b.append(this.isPaid);
        b.append(", ");
        b.append("startDateTime=");
        b.append(this.startDateTime);
        b.append(", ");
        b.append("endDateTime=");
        b.append(this.endDateTime);
        b.append(", ");
        b.append("code=");
        b.append(this.code);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("theme=");
        b.append(this.theme);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/ShiftActivity.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.enums.ScheduleEntityTheme;

@JsonPropertyOrder({
    "@odata.type", 
    "code", 
    "displayName", 
    "endDateTime", 
    "isPaid", 
    "startDateTime", 
    "theme"})
@JsonInclude(Include.NON_NULL)
public class ShiftActivity implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("code")
    protected String code;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("endDateTime")
    protected OffsetDateTime endDateTime;

    @JsonProperty("isPaid")
    protected Boolean isPaid;

    @JsonProperty("startDateTime")
    protected OffsetDateTime startDateTime;

    @JsonProperty("theme")
    protected ScheduleEntityTheme theme;

    protected ShiftActivity() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.shiftActivity";
    }

    @Property(name="code")
    @JsonIgnore
    public Optional<String> getCode() {
        return Optional.ofNullable(code);
    }

    public ShiftActivity withCode(String code) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.code = code;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ShiftActivity withDisplayName(String displayName) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="endDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getEndDateTime() {
        return Optional.ofNullable(endDateTime);
    }

    public ShiftActivity withEndDateTime(OffsetDateTime endDateTime) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.endDateTime = endDateTime;
        return _x;
    }

    @Property(name="isPaid")
    @JsonIgnore
    public Optional<Boolean> getIsPaid() {
        return Optional.ofNullable(isPaid);
    }

    public ShiftActivity withIsPaid(Boolean isPaid) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.isPaid = isPaid;
        return _x;
    }

    @Property(name="startDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getStartDateTime() {
        return Optional.ofNullable(startDateTime);
    }

    public ShiftActivity withStartDateTime(OffsetDateTime startDateTime) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.startDateTime = startDateTime;
        return _x;
    }

    @Property(name="theme")
    @JsonIgnore
    public Optional<ScheduleEntityTheme> getTheme() {
        return Optional.ofNullable(theme);
    }

    public ShiftActivity withTheme(ScheduleEntityTheme theme) {
        ShiftActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftActivity");
        _x.theme = theme;
        return _x;
    }

    public ShiftActivity withUnmappedField(String name, Object value) {
        ShiftActivity _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String code;
        private String displayName;
        private OffsetDateTime endDateTime;
        private Boolean isPaid;
        private OffsetDateTime startDateTime;
        private ScheduleEntityTheme theme;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder code(String code) {
            this.code = code;
            this.changedFields = changedFields.add("code");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder endDateTime(OffsetDateTime endDateTime) {
            this.endDateTime = endDateTime;
            this.changedFields = changedFields.add("endDateTime");
            return this;
        }

        public Builder isPaid(Boolean isPaid) {
            this.isPaid = isPaid;
            this.changedFields = changedFields.add("isPaid");
            return this;
        }

        public Builder startDateTime(OffsetDateTime startDateTime) {
            this.startDateTime = startDateTime;
            this.changedFields = changedFields.add("startDateTime");
            return this;
        }

        public Builder theme(ScheduleEntityTheme theme) {
            this.theme = theme;
            this.changedFields = changedFields.add("theme");
            return this;
        }

        public ShiftActivity build() {
            ShiftActivity _x = new ShiftActivity();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.shiftActivity";
            _x.code = code;
            _x.displayName = displayName;
            _x.endDateTime = endDateTime;
            _x.isPaid = isPaid;
            _x.startDateTime = startDateTime;
            _x.theme = theme;
            return _x;
        }
    }

    private ShiftActivity _copy() {
        ShiftActivity _x = new ShiftActivity();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.code = code;
        _x.displayName = displayName;
        _x.endDateTime = endDateTime;
        _x.isPaid = isPaid;
        _x.startDateTime = startDateTime;
        _x.theme = theme;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ShiftActivity[");
        b.append("code=");
        b.append(this.code);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("endDateTime=");
        b.append(this.endDateTime);
        b.append(", ");
        b.append("isPaid=");
        b.append(this.isPaid);
        b.append(", ");
        b.append("startDateTime=");
        b.append(this.startDateTime);
        b.append(", ");
        b.append("theme=");
        b.append(this.theme);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
